"use strict";

const moment = require('moment');

const logger = require('komodo-sdk/logger');

const commands = require('../command-group');
const commandError = require('./error');
const coreapi = require('../coreapi');

const coreEndpoint = '/prepaid/buy';

function generateRequestId(product, destination) {
    return `AUTO_${ product.toUpperCase() }_${ destination }_${ moment().format('YYYYMMDD') }`;
}

function help() {
    return `Untuk pembelian, ketik perintah dengan format: <KODEPRODUK>.<NOMORTUJUAN>.<PIN>`;
}

function execute(tokens, params, cb) {
    if (!tokens || tokens.length < 3) {
        const responseParams = {
            body: `${ commandError.ERR_INVALID_FORMAT }. ${ help() }`
        }

        cb(null, null, responseParams);
        return;
    }

    if (commands[ tokens[0] ] !== 'buy') {
        tokens.unshift('buy');
        logger.verbose('Rearrange tokens', {tokens: tokens});
    }

    const coreParams = {
        origin: params.origin,
        report_ip: params.report_ip,
        report_port: params.report_port,
        terminal_name: params.from,
        product_name: tokens[1].toUpperCase(),
        destination: tokens[2],
        password: tokens[3],
        request_id: tokens[4] || generateRequestId(tokens[1], tokens[2]),
        postpaid: 0
    };

    coreapi(coreEndpoint, coreParams, 'GET', cb);
}

module.exports = execute;