"use strict";

const logger = require('komodo-sdk/logger');

const commandParser = require('../command-parser');

const commandError = require('./error');

const handlerAddBalance = require('./addbalance');
const handlerAddDownline = require('./adddownline');
const handlerAddTerminal = require('./addterminal');
const handlerBalance = require('./balance');
const handlerBuy = require('./buy');
const handlerChangePin = require('./changepin');
const handlerDaySummary = require('./daysummary');
const handlerDepositTicket = require('./depositticket');
const handlerDisableDownline = require('./disabledownline');
const handlerDownlineInfo = require('./downlineinfo');
const handlerEnableDownline = require('./enabledownline');
const handlerHelp = require('./help');
const handlerListDownline = require('./listdownline');
const handlerListTerminal = require('./listterminal');
const handlerPrice = require('./price');
const handlerSupplierBalances = require('./supplierbalances');
const handlerTransferBalance = require('./transferbalance');

function execute(msg, params, cb) {

    if ( typeof msg !== 'string' || !msg.trim() ) {
        cb(commandError.ERR_EMPTY_MESSAGE);
        return;
    }
    
    const tokens = commandParser.splitToken(msg);
    const commandGroup = commandParser.extractCommandGroup(tokens);
    logger.verbose('Got new message from partner', {msg: msg, params: params, tokens: tokens, commandGroup: commandGroup});

    if (!commandGroup || commandGroup === 'buy') {
        handlerBuy(tokens, params, cb);
    }
    else if (commandGroup === 'balance') {
        handlerBalance(tokens, params, cb);
    }
    else if (commandGroup === 'addbalance') {
        handlerAddBalance(tokens, params, cb);
    }
    else if (commandGroup === 'transferbalance') {
        handlerTransferBalance(tokens, params, cb);
    }
    else if (commandGroup === 'price') {
        handlerPrice(tokens, params, cb);
    }
    else if (commandGroup === 'listdownline') {
        handlerListDownline(tokens, params, cb);
    }
    else if (commandGroup === 'downlineinfo') {
        handlerDownlineInfo(tokens, params, cb);
    }
    else if (commandGroup === 'adddownline') {
        handlerAddDownline(tokens, params, cb);
    }
    else if (commandGroup === 'listterminal') {
        handlerListTerminal(tokens, params, cb);
    }
    else if (commandGroup === 'addterminal') {
        handlerAddTerminal(tokens, params, cb);
    }
    else if (commandGroup === 'changepin') {
        handlerChangePin(tokens, params, cb);
    }
    else if (commandGroup === 'enabledownline') {
        handlerEnableDownline(tokens, params, cb);
    }
    else if (commandGroup === 'daysummary') {
        handlerDaySummary(tokens, params, cb);
    }
    else if (commandGroup === 'depositticket') {
        handlerDepositTicket(tokens, params, cb);
    }
    else if (commandGroup === 'disabledownline') {
        handlerDisableDownline(tokens, params, cb);
    }
    else if (commandGroup === 'supplierbalances') {
        handlerSupplierBalances(tokens, params, cb);
    }
    else if (commandGroup === 'help') {
        handlerHelp(cb)
    }
    else {
        cb(commandError.ERR_NOT_IMPLEMENTED);
    }
}

module.exports = execute;